@@ -1206,7 +1206,12 @@ class Transaction(object):
         """
         operation = tx.get('operation', Transaction.CREATE) if isinstance(tx, dict) else Transaction.CREATE
         cls = Transaction.resolve_class(operation)
-
+        try:
+            tx.pop("app_key")
+            tx.pop("app_id")
+        except KeyError:
+            pass
+        
         if not skip_schema_validation:
             cls.validate_id(tx)
             cls.validate_schema(tx)
